### R code from Spatial Exploratory Data Analysis
### T. Laurent



###################################################
### required packages
###################################################
install.packages(c("classInt", "RColorBrewer", 
  "GeoXp", "Guerry", "spatstat"))


###################################################
### Slide p.4
###################################################
require("rgdal")
require("maptools")

source("preambule.R")


###################################################
### slide p.6
###################################################
pays.af<-c("Seychelles","Equatorial Guinea","Gabon","Botswana",
"Mauritius","South Africa","Namibia","Angola","Swaziland","Congo",
"Cape Verde","Ghana","Sudan","Djibouti","Nigeria","Sao Tome and Principe",
"Cameroon","Lesotho","Gambia, The","Chad","Senegal","Kenya","Ivory Coast",
"Zambia","Burkina Faso","Tanzania, United Republic of","Benin","Rwanda",
"Uganda","Comoros","Guinea-Bissau","Mali","Mozambique","Guinea","Ethiopia",
"Madagascar", "Malawi","Togo","Sierra Leone","Niger","Central African Republic",
"Eritrea","Burundi","Somalia","Zimbabwe","Liberia","Zaire")
africa.sub=world[world@data$NOM%in%pays.af,]

africa.df<-data.frame(pib=c(25000,26500,18100,15700,15400,11300,7800,6100,
5700,4600,4400,3300,2500,2600,2700,2100,2300,2100,1900,2500,2000,1800,1700,
1700,1400,1600,1600,1400,1400,1300,1200,1100,1200,1100,1300,900,800,1100,
1300,800,900,700,600,600,600,700,400),row.names=pays.af)		


###################################################
### slide p.7
###################################################
africa.sub<-SpatialPolygonsDataFrame(africa.sub,africa.df)
africa <- spRbind(northAf, africa.sub)
africa@data$region <- factor(c("N","N","N","N","N","N","O",
"O","C","E","E","O","O","O","E","O","O","C","E","O","O",
"O","E","O","O","C","O","O","C","O","E", "E","C","C","C",
"C","E","E","E","E","C","E","E","E","E","E","E","Au","Au",
"E","Au","Au","Au"))


###################################################
### slide p.8
###################################################
pal.reg <- c("red","pink","orange",
"blue","green")


ind=as.numeric(africa@data$region)
plot(africa, col=pal.reg[ind])
title("Africa's regions")
legend("topright",legend=c("Aust","Cent",
"East","North","West"),cex=0.8,
title="Region",fill=pal.reg)


###################################################
### slide p.9
###################################################
require("classInt")
pib <- africa@data$pib

require("RColorBrewer")
plotclr <- brewer.pal(5,"Blues")
pal1 <- plotclr[c(1,5)]
opar <- par(mfrow=c(2,2))
plot(classIntervals(pib,5,"equal"),
 pal=pal1, main="equal")
plot(classIntervals(pib,5,"quantile"), 
 pal=pal1, main="quantile")
plot(classIntervals(pib,5,"kmeans"), 
 pal=pal1, main="K-means")
plot(classIntervals(pib,5,"jenks"), 
 pal=pal1, main="Jenks")
par(opar)


###################################################
### slide p.11
###################################################
bk=round(classIntervals(pib, 5,"kmeans")$brks, 
digits=1)

ind=findInterval(pib, bk, all.inside=TRUE)
plot(africa, col=plotclr[ind])
decoup <- c("<=1500","]1500;3850]",
"]3850;10500]","]10500;21550]",">21550")
legend("bottomleft", legend = decoup, 
cex = 0.8,title="GDP", fill=plotclr)
SpatialPolygonsRescale(layout.north.arrow(1), 
offset = c(50,-30), scale = 5, plot.grid=F)
title("GDP per inhabitant")


###################################################
### slide p.12
###################################################

bubble(seisme.jp, "Magnitude")


###################################################
### slide p.19
###################################################
require("GeoXp")
require("Guerry")


gfrance85@data$Crime_pers<-1000/gfrance85@data$Crime_pers
gfrance85@data$Crime_prop<-1000/gfrance85@data$Crime_prop


row.names(gfrance85) <- as.character(gfrance85@data$Department)

spplot(gfrance85,"Crime_pers",col.regions=rev(heat.colors(16)))
spplot(gfrance85,"Crime_prop",col.regions=rev(heat.colors(16)))


###################################################
### slide p.20-25
###################################################
dbledensitymap(gfrance85,c("Crime_pers", "Crime_prop"), xlab = 
  c("Crimesagainstpersons", "Crimesagainstproperty"),identify=T)

driftmap(gfrance85, "Crime_pers")
driftmap(gfrance85, "Crime_prop")

scattermap(gfrance85,c("Literacy", "Crime_prop"),
  xlab="Literacy",ylab="Crimes",identify=TRUE)

polyboxplotmap(gfrance85,c("MainCity","Crime_prop"),identify=TRUE)

ginimap(gfrance85, "Donations")

pcamap(gfrance85, c(7:12, 14:26),identify=TRUE)


###################################################
### slide p.28
###################################################
require("spatstat") 
bb <- bbox(japan2)
W = owin(bb[1,], bb[2,])

wp.seisme <- ppp(x=seisme.jp2@coords[,1],
y = seisme.jp2@coords[,2], window=W)

marks(wp.seisme) <- seisme.jp2@data$Magnitude


###################################################
### slide p.29
###################################################
bw.diggle(wp.seisme)

D.seisme<- density(wp.seisme, sigma=30000)

plot(D.seisme, main="Spatial Intensity")
plot(japan2, add=TRUE, border="white")


###################################################
### slide p.30
###################################################
data(meuse)
coordinates(meuse) <- ~x+y
proj4string(meuse) <- CRS("+init=epsg:28992")

require("rgeos")
test <- gBuffer(meuse, width=250)
W = as(test, "owin")
meuse.ppp <- ppp(meuse$x, meuse$y, window=W)
marks(meuse.ppp) <- meuse$zinc

dens.zinc <- idw(meuse.ppp, 2)


###################################################
### slide p.31
###################################################

op = par(mfrow=c(2,2), mar=c(0,0,3.3,0))
plot(meuse.ppp,
 main="Concentrations in zinc")
plot(nnmark(meuse.ppp), 
 main="Mark of Nearest Neighbour")
plot(Smooth(meuse.ppp), 
 main="Spatial smoothing")
plot(dens.zinc, 
 main="Inv-dist weighted smoothing")
par(op)
